jsonrpc

package
v0.0.0-...-17a4a10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package jsonrpc exposes part of a JSON-RPC v2 implementation for use by mcp transport authors.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EncodeMessage

func EncodeMessage(msg Message) ([]byte, error)

EncodeMessage serializes a JSON-RPC message to its wire format.

Types

type ID

type ID = jsonrpc2.ID

ID is a JSON-RPC request ID.

func MakeID

func MakeID(v any) (ID, error)

MakeID coerces the given Go value to an ID. The value should be the default JSON marshaling of a Request identifier: nil, float64, or string.

Returns an error if the value type was not a valid Request ID type.

type Message

type Message = jsonrpc2.Message

Message is a JSON-RPC message.

func DecodeMessage

func DecodeMessage(data []byte) (Message, error)

DecodeMessage deserializes JSON-RPC wire format data into a Message. It returns either a Request or Response based on the message content.

type Request

type Request = jsonrpc2.Request

Request is a JSON-RPC request.

type Response

type Response = jsonrpc2.Response

Response is a JSON-RPC response.

Jump to